@@ -10,7 +10,7 @@
 ## 'fixed' specifies the values of param elements that are fixed.  Values that are not fixed should be denoted NA.  
 ## All values in "fixed" must be numbers
 
-# options for constraint
+# options for model
 # "ignore" user is going to specify constraints with fixed and free
 # Q & R  "unconstrained", "diagonal and unequal", "diagonal and all equal", "equalvarcov"
 # U  "unconstrained", "all equal"
@@ -20,13 +20,13 @@
 # x0 "unconstrained" "equal" ("prior" not yet implemented)
 # V0 No options, because it is determined by x0. if x0 is "fixed" then V0 must be 0; if x0 is prior then V0 must be prior)
 
-# If constraint is passed in for R, B, U, Q or x0, then the corrsponding elements in fixed and free should not be passed in
-# because 'constraint' is just a helper to set 'fixed' and 'free' for certain common cases.
-# However, some params can be set with 'constraint' and others with 'fixed' and 'free'
+# If model is passed in for R, B, U, Q or x0, then the corrsponding elements in fixed and free should not be passed in
+# because 'model' is just a helper to set 'fixed' and 'free' for certain common cases.
+# However, some params can be set with 'model' and others with 'fixed' and 'free'
 
 popWrap <- function(y, allowed,
     inits=NULL,
-    constraint=NULL,
+    model=NULL,
     fixed=NULL, free=NULL, 
     miss.value=NULL,  
     control=NULL,
@@ -35,23 +35,23 @@ popWrap <- function(y, allowed,
 {
   
 ### Specify some holders
-wrapper.el = c("data", "m", "inits", "constraint", "fixed", "free", "miss.value", "control", "method")
+wrapper.el = c("data", "m", "inits", "model", "fixed", "free", "miss.value", "control", "method")
 
-req.args = c("inits", "constraint", "miss.value", "control", "method")
+req.args = c("inits", "model", "miss.value", "control", "method")
 # model.elem   is specified in MARSSsettings
 
-# Can't do anything if constraint is specified wrong
-if(!is.null(constraint) && !is.list(constraint))
-    stop("Stopped in popWrap() because constraint needs to be passed in as a list or left off (to use defaults).\n", call.=FALSE)
+# Can't do anything if model is specified wrong
+if(!is.null(model) && !is.list(model))
+    stop("Stopped in popWrap() because model needs to be passed in as a list or left off (to use defaults).\n", call.=FALSE)
 
-### If some elements are specified in both constraint and fixed or free, then use fixed/free and warn (b501)
+### If some elements are specified in both model and fixed or free, then use fixed/free and warn (b501)
 both.cons.fixed.free = FALSE
 for(i in unique(c(names(fixed), names(free))) )   {
-      if(is.null(constraint)) constraint=list()
-      if(!is.null(constraint[[i]])) both.cons.fixed.free = TRUE
-      constraint[[i]] = "use fixed/free"
+      if(is.null(model)) model=list()
+      if(!is.null(model[[i]])) both.cons.fixed.free = TRUE
+      model[[i]] = "use fixed/free"
       } 
-if(!silent && both.cons.fixed.free) warning("popWrap: both constraint and fixed (and/or free) specified for one of the model elements.\nfixed/free will be used and constraint arg ignored.\n", call.=FALSE)
+if(!silent && both.cons.fixed.free) warning("popWrap: both model and fixed (and/or free) specified for one of the model elements.\nfixed/free will be used and model arg ignored.\n", call.=FALSE)
 
 defaults = alldefaults[[method]] #from MARSSsettings
 ## Now set defaults if needed, first deal with case where arg not passed in all
@@ -77,10 +77,10 @@ for(el in req.args) {
 ## KW Set m
 n = ifelse(is.null(dim(y)), 1, dim(y)[1])
 m = NA
-if (identical(constraint$Z, "use fixed/free")) m = dim(fixed$Z)[2]
-if (identical(constraint$Z, "identity")) m = n
-if (is.factor(constraint$Z)) m = length(levels(constraint$Z)) 
-if (is.matrix(constraint$Z)) m = dim(constraint$Z)[2] 
+if (identical(model$Z, "use fixed/free")) m = dim(fixed$Z)[2]
+if (identical(model$Z, "identity")) m = n
+if (is.factor(model$Z)) m = length(levels(model$Z)) 
+if (is.matrix(model$Z)) m = dim(model$Z)[2] 
 
 # if some of the elements of MCinit bounds were passed in but not others, use defaults
     if(!is.list(control$boundsInits))
@@ -104,13 +104,13 @@ if(!silent && is.null(control$abstol) && !is.null(control$min.iter.conv.test) &&
 }
 
 ## Create popWrap object
-  wrapperObj <- list(data=y, m=m, inits=inits, constraint=constraint, fixed=fixed, free=free, miss.value=miss.value, control=control, method=method)
+  wrapperObj <- list(data=y, m=m, inits=inits, model=model, fixed=fixed, free=free, miss.value=miss.value, control=control, method=method)
   class(wrapperObj) <- "popWrap"
 
   ## checkPopWrap just checks that everything needed is present and
-  ## the user didn't pass in any disallowed constraints that would prevent as.marss() from working
+  ## the user didn't pass in any disallowed model structures that would prevent as.marss() from working
   ## mis-specified fixed/free will be caught by is.marssm()
-  ## as.marssm() should construct the fixed/free from the constraint strings (unless "use fixed/free", then don't do anything)
+  ## as.marssm() should construct the fixed/free from the model list strings (unless "use fixed/free", then don't do anything)
   ## the exception is if either fixed or free is have no NAs, in that case, as.marssm() can construct the corresponding fixed/free
   ## e.g. fixed[[el]] = array(NA,dim=dim(fixed[[el]]))  Note dim not checked here, that will be caught by is.marssm()
   checkPopWrap(wrapperObj, wrapper.el, allowed, silent=silent)
