@@ -8,8 +8,10 @@ print.marssMLE <- function (x, digits = max(3, getOption("digits")-4), ...)
       cat("\nMARSS fit is\n")
       cat(paste("Estimation method:", x$method, "\n"))
 	    if(x$control$MCInit) cat("Monte Carlo initialization with", x$controlnumInits, "random starts. \n")
-      if(is.null(x$control$abstol)){ cat(paste("Convergence test: log-log plot with slope tol of", x$control$conv.test.slope.tol, "\n"))
-      }else cat(paste("Convergence test: delta logLik with abstol of", x$control$abstol, "\n"))
+      if(("conv.test.slope.tol" %in% names(alldefaults[[x$method]])) & is.null(x$control$abstol)) 
+            cat(paste("Convergence test: log-log plot with slope tol of", x$control$conv.test.slope.tol, "\n"))
+      if(("conv.test.slope.tol" %in% names(alldefaults[[x$method]])) & !is.null(x$control$abstol))
+            cat(paste("Convergence test: delta logLik with abstol of", x$control$abstol, "\n"))
 	    if (x$convergence==0){
         if( x$method %in% optim.methods || x$numIter>x$control$minit ){ cat("Estimation converged in", x$numIter,"iterations. \n")
 	       }else cat("Algorithm ran", x$numIter,"(=minit) iterations and convergence was reached. \n")
